@@ -41,8 +41,8 @@ NUMBER_OF_GAMES = 7
 # MULTIPLIER TO MATCH PU WITH ORIGINAL SETS
 PU_MULTIPLIER = {
     '2000': 1.75,
-    '2001': 2.9,
-    '2002': 3.0,
+    '2001': 2.25,
+    '2002': 2.7,
     '2003': 2.0,
     '2004': 2.05,
     '2005': 2.25,
@@ -547,9 +547,9 @@ POINT_CATEGORY_WEIGHTS = {
         },
         'relief_pitcher': {
             'ip': 0, # IP IS ADJUSTED ELSEWHERE
-            'onbase': 110,
+            'onbase': 145,
             'average': 25,
-            'slugging': 125
+            'slugging': 120
         }
     },
     '2002': {
@@ -836,7 +836,7 @@ POINTS_NORMALIZER_MULTIPLIER = {
     '2001': {
         'position_player': 0.65,
         'starting_pitcher': 0.70,
-        'relief_pitcher': 0.85,
+        'relief_pitcher': 0.72,
     },
     '2002': {
         'position_player': 0.85,
@@ -1494,7 +1494,7 @@ IMAGE_LOCATIONS = {
         '2005': (1344,1911),
     },
     'number': {
-        '2003': (135,1785),
+        '2003': (120,1785),
         '2004': (1191,1911),
         '2005': (1191,1911),
     },
@@ -1507,13 +1507,21 @@ IMAGE_LOCATIONS = {
         '2005': (1071,1164),
     },
     'version': {
-        '2000': (1374,2050),
-        '2001': (1374,2050),
+        '2000': (1360,2050),
+        '2001': (1360,2050),
         '2002': (164,2011),
         '2003': (752,1810),
         '2004': (1355,2069),
         '2005': (1355,2069),
     },
+    'expansion': {
+        '2000': (1287,1855),
+        '2001': (1287,1855),
+        '2002': (652,1770),
+        '2003': (275,1782),
+        '2004': (1060,1910),
+        '2005': (1060,1910),
+    },
 }
 
 """ LIST OF ICON IMAGE COORDINATES FOR EACH ICON INDEX """
@@ -1652,6 +1660,8 @@ TEAM_LOGO_ALTERNATES = {
     },
     'NYM': {
         '1': list(range(1962,1993)),
+        '2': list(range(1993,1998)),
+        '3': list(range(1998,2011)),
     },
     'NYY': {
         '1': list(range(1900,1950)),
